@@ -19,11 +19,13 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
 #include "engineproxy.h"
-#include "types.h"
-#include "marshalers.h"
+
+#include "global.h"
 #include "ibusimpl.h"
-#include "option.h"
+#include "marshalers.h"
+#include "types.h"
 
 struct _BusEngineProxy {
     IBusProxy parent;
@@ -53,11 +55,18 @@ struct _BusEngineProxy {
     IBusText *surrounding_text;
     guint     surrounding_cursor_pos;
     guint     selection_anchor_pos;
+
+    /* cached properties */
+    IBusPropList *prop_list;
 };
 
 struct _BusEngineProxyClass {
     IBusProxyClass parent;
     /* class members */
+    void (* register_properties) (BusEngineProxy      *engine,
+                                  IBusPropList *prop_list);
+    void (* update_property) (BusEngineProxy      *engine,
+                              IBusProperty *prop);
 };
 
 enum {
@@ -91,6 +100,7 @@ enum {
 static guint    engine_signals[LAST_SIGNAL] = { 0 };
 
 static IBusText *text_empty = NULL;
+static IBusPropList *prop_list_empty = NULL;
 
 /* functions prototype */
 static void     bus_engine_proxy_set_property   (BusEngineProxy      *engine,
@@ -101,6 +111,12 @@ static void     bus_engine_proxy_get_property   (BusEngineProxy      *engine,
                                                  guint                prop_id,
                                                  GValue              *value,
                                                  GParamSpec          *pspec);
+static void     bus_engine_proxy_real_register_properties
+                                                (BusEngineProxy      *engine,
+                                                 IBusPropList        *prop_list);
+static void     bus_engine_proxy_real_update_property
+                                                (BusEngineProxy      *engine,
+                                                 IBusProperty        *prop);
 static void     bus_engine_proxy_real_destroy   (IBusProxy           *proxy);
 static void     bus_engine_proxy_g_signal       (GDBusProxy          *proxy,
                                                  const gchar         *sender_name,
@@ -123,6 +139,9 @@ bus_engine_proxy_class_init (BusEngineProxyClass *class)
     gobject_class->set_property = (GObjectSetPropertyFunc)bus_engine_proxy_set_property;
     gobject_class->get_property = (GObjectGetPropertyFunc)bus_engine_proxy_get_property;
 
+    class->register_properties = bus_engine_proxy_real_register_properties;
+    class->update_property = bus_engine_proxy_real_update_property;
+
     IBUS_PROXY_CLASS (class)->destroy = bus_engine_proxy_real_destroy;
     G_DBUS_PROXY_CLASS (class)->g_signal = bus_engine_proxy_g_signal;
 
@@ -332,7 +351,7 @@ bus_engine_proxy_class_init (BusEngineProxyClass *class)
         g_signal_new (I_("register-properties"),
             G_TYPE_FROM_CLASS (class),
             G_SIGNAL_RUN_LAST,
-            0,
+            G_STRUCT_OFFSET (BusEngineProxyClass, register_properties),
             NULL, NULL,
             bus_marshal_VOID__OBJECT,
             G_TYPE_NONE,
@@ -343,7 +362,7 @@ bus_engine_proxy_class_init (BusEngineProxyClass *class)
         g_signal_new (I_("update-property"),
             G_TYPE_FROM_CLASS (class),
             G_SIGNAL_RUN_LAST,
-            0,
+            G_STRUCT_OFFSET (BusEngineProxyClass, update_property),
             NULL, NULL,
             bus_marshal_VOID__OBJECT,
             G_TYPE_NONE,
@@ -352,12 +371,16 @@ bus_engine_proxy_class_init (BusEngineProxyClass *class)
 
     text_empty = ibus_text_new_from_static_string ("");
     g_object_ref_sink (text_empty);
+
+    prop_list_empty = ibus_prop_list_new ();
+    g_object_ref_sink (prop_list_empty);
 }
 
 static void
 bus_engine_proxy_init (BusEngineProxy *engine)
 {
     engine->surrounding_text = g_object_ref_sink (text_empty);
+    engine->prop_list = g_object_ref_sink (prop_list_empty);
 }
 
 static void
@@ -392,6 +415,26 @@ bus_engine_proxy_get_property (BusEngineProxy *engine,
 
 }
 
+static void
+bus_engine_proxy_real_register_properties (BusEngineProxy *engine,
+                                           IBusPropList   *prop_list)
+{
+    g_assert (IBUS_IS_PROP_LIST (prop_list));
+
+    if (engine->prop_list != prop_list_empty)
+        g_object_unref (engine->prop_list);
+    engine->prop_list = (IBusPropList *) g_object_ref_sink (prop_list);
+}
+
+static void
+bus_engine_proxy_real_update_property (BusEngineProxy *engine,
+                                       IBusProperty   *prop)
+{
+    g_return_if_fail (prop);
+    if (engine->prop_list)
+        ibus_prop_list_update_property (engine->prop_list, prop);
+}
+
 static void
 bus_engine_proxy_real_destroy (IBusProxy *proxy)
 {
@@ -412,6 +455,11 @@ bus_engine_proxy_real_destroy (IBusProxy *proxy)
         engine->surrounding_text = NULL;
     }
 
+    if (engine->prop_list) {
+        g_object_unref (engine->prop_list);
+        engine->prop_list = NULL;
+    }
+
     IBUS_PROXY_CLASS (bus_engine_proxy_parent_class)->destroy ((IBusProxy *)engine);
 }
 
@@ -908,7 +956,7 @@ bus_engine_proxy_process_key_event (BusEngineProxy      *engine,
             keymap = BUS_DEFAULT_KEYMAP;
         if (keymap != NULL) {
             guint t = ibus_keymap_lookup_keysym (keymap, keycode, state);
-            if (t != IBUS_VoidSymbol) {
+            if (t != IBUS_KEY_VoidSymbol) {
                 keyval = t;
             }
         }
@@ -1201,6 +1249,14 @@ bus_engine_proxy_get_desc (BusEngineProxy *engine)
     return engine->desc;
 }
 
+IBusPropList *
+bus_engine_proxy_get_properties (BusEngineProxy *engine)
+{
+    g_assert (BUS_IS_ENGINE_PROXY (engine));
+
+    return engine->prop_list;
+}
+
 gboolean
 bus_engine_proxy_is_enabled (BusEngineProxy *engine)
 {
